@@ -21,11 +21,6 @@ extends('Test::Run::Base');
 
 use Test::Run::Base::Plugger;
 
-sub _get_private_fields
-{
-    return [qw(_plug_helpers)];
-}
-
 has '_plug_helpers' => (is => "rw", isa => "HashRef");
 
 sub _init
@@ -161,6 +156,7 @@ L<Test::Run::Base>, L<Test::Run::Obj>, L<Test::Run::Core>
 This file is freely distributable under the MIT X11 license.
 
 L<http://www.opensource.org/licenses/mit-license.php>
+
 =head1 AUTHOR
 
 Shlomi Fish, L<http://www.shlomifish.org/>.
